@@ -1,5 +1,4 @@
-pulkrob.chisq <-
-function(model, catvars) {
+pulkrob.chisq <- function(model, catvars) {
   epi.cp.pulkrob <- function(dat){
     # adapted from epiR::epi.cp() by Mark Stevenson et al
     ndat <- data.frame(id = 1:nrow(dat), dat)
@@ -53,11 +52,15 @@ function(model, catvars) {
   dfobs <- merge(x = dfobs, y = yhat[, c("id", "covpatsplit")], by = "id", all.x = TRUE)
   dfobsmelt <- melt(dfobs[, -1], id.vars = "covpatsplit")
   observed <- cast(dfobsmelt, covpatsplit ~ value, length)
-  observed <- observed[order(c(1, names(observed[, 2:ncol(observed)])))]
+  observed.cols <- observed[, names(observed[, 2:ncol(observed)])]
+  observed.cols <- observed.cols[order(names(observed[, 2:ncol(observed)]))]
+  observed <- cbind(covatsplit = observed[, 1], observed.cols)
   dfexp <- yhat[, !colnames(yhat) %in% c("id", "covpat", "med", "score")]
   dfexpmelt <- melt(dfexp, id.vars = ncol(dfexp))
   expected <- cast(dfexpmelt, covpatsplit ~ variable, sum)
-  expected <- expected[order(c(1, names(expected[, 2:ncol(expected)])))]
+  expected.cols <- expected[, names(expected[, 2:ncol(expected)])]
+  expected.cols <- expected.cols[order(names(expected[, 2:ncol(expected)]))]
+  expected <- cbind(covatsplit = expected[, 1], expected.cols)
   stddiffs <- abs(observed[, 2:ncol(observed)] - expected[, 2:ncol(expected)]) / sqrt(expected[, 2:ncol(expected)])
   if (any(expected[, 2:ncol(expected)] < 1))
     warning("At least one cell in the expected frequencies table is < 1. Chi-square approximation may be incorrect.")
